<?php
// Own namespace
namespace CoreFramework\Factory\Connection;

// Import framework stuff
use CoreFramework\Factory\ObjectFactory;
use CoreFramework\Registry\Registry;

/**
 * A factory class for ShareableInfo
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2017 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class ConnectionInfoFactory extends ObjectFactory {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Returns a singleton (registry-based) ShareableInfo instance
	 *
	 * @param	$protocolName	Name of protocol (e.g. 'tcp')
	 * @param	$type			Connection type ('listener' or 'helper')
	 * @return	$infoInstance	An instance of a ShareableInfo class
	 */
	public static final function createConnectionInfoInstance ($protocolName, $type) {
		// Generate key
		$key = 'connection_info_' . $protocolName . '_' . $type;

		// If there is no info?
		if (Registry::getRegistry()->instanceExists($key)) {
			// Get info from registry
			$infoInstance = Registry::getRegistry()->getInstance($key);
		} else {
			// Get the info instance
			$infoInstance = self::createObjectByConfiguredName('connection_info_class');

			// Add it to the registry
			Registry::getRegistry()->addInstance($key, $infoInstance);
		}

		// Return the instance
		return $infoInstance;
	}
}

// [EOF]
?>
